@@ -12,7 +12,8 @@ class Adun(Executor):
         self.runner = runner
 
     def execute(self, job, one_container=False):
-        logging.info('Job started: %s' % to_json(job))
+        logging.info('Job started: %s' % job.job_id)
+        logging.debug('Job: %s' % to_json(job))
 
         if one_container:
             return self.exec_wrapper_full(job)
@@ -44,8 +45,6 @@ class Adun(Executor):
         return result
 
     def exec_wrapper_job(self, job):
-        # name = job.args.get('$method') or job.args.get('$stage') or 'initial'
-        # job_dir = 'job_%s_%s_%s' % (job.wrapper_id, name, job.job_id)
         job_dir = job.job_id
         os.mkdir(job_dir)
         os.chdir(job_dir)
